SELECT S_Kunde.Kunde as "S_Kunde.Kunde",
  S_Adresse.AdressNr as "S_Adresse.AdressNr",
  S_Adresse.Name1 as "S_Adresse.Name1",
  S_Adresse.Staat as "S_Adresse.Staat",
  S_Adresse.Ort as "S_Adresse.Ort",
  S_Adresse.Suchbegriff as "S_Adresse.Suchbegriff",
  S_Adresse.Selektion as "S_Adresse.Selektion",
  S_Adresse.BriefAnrede as "S_Adresse.BriefAnrede",
  S_Adresse.Anrede as "S_Adresse.Anrede",
  S_Adresse.Titel as "S_Adresse.Titel",
  S_Adresse.Vorname as "S_Adresse.Vorname",
  S_Adresse.Name2 as "S_Adresse.Name2",
  S_Adresse.Name3 as "S_Adresse.Name3",
  S_Adresse.PLZ as "S_Adresse.PLZ",
  S_Adresse.CityPrefix as "S_Adresse.CityPrefix",
  S_Adresse.CityPostfix as "S_Adresse.CityPostfix",
  S_Adresse.StreetPrefix as "S_Adresse.StreetPrefix",
  S_Adresse.Strasse as "S_Adresse.Strasse",
  S_Adresse.StreetPostfix as "S_Adresse.StreetPostfix",
  S_Adresse.Hausnummer as "S_Adresse.Hausnummer",
  S_Adresse.Bundesland as "S_Adresse.Bundesland",
  S_Adresse.PLZ_Postfach as "S_Adresse.PLZ_Postfach",
  S_Adresse.Postfach as "S_Adresse.Postfach",
  S_Adresse.Telefonbuch as "S_Adresse.Telefonbuch",
  S_Adresse.EMail as "S_Adresse.EMail",
  S_Adresse.HomePage as "S_Adresse.HomePage",
  S_Adresse.Handy as "S_Adresse.Handy",
  S_Adresse.Telefon as "S_Adresse.Telefon",
  S_Adresse.AutoTelefon as "S_Adresse.AutoTelefon",
  S_Adresse.Telefax as "S_Adresse.Telefax",
  S_Adresse.Telefon2 as "S_Adresse.Telefon2",
  S_Adresse.Telefax2 as "S_Adresse.Telefax2",
  S_Adresse.Longitude as "S_Adresse.Longitude",
  S_Adresse.Latitude as "S_Adresse.Latitude",
  S_Kunde.Suchbegriff as "S_Kunde.Suchbegriff",
  S_Kunde.Selektion as "S_Kunde.Selektion",
  S_Kunde.Verteilergruppe as "S_Kunde.Verteilergruppe",
  S_Kunde.Branche as "S_Kunde.Branche",
  S_Kunde.Region as "S_Kunde.Region",
  S_Kunde.Sachbearbeiter as "S_Kunde.Sachbearbeiter",
  S_Kunde.Sprache as "S_Kunde.Sprache",
  S_Kunde.Abc_klasse as "S_Kunde.Abc_klasse",
  S_Kunde.Artikelstatistik as "S_Kunde.Artikelstatistik",
  S_Kunde.Webshop as "S_Kunde.Webshop",
  S_Kunde.Bestandsfaktor as "S_Kunde.Bestandsfaktor",
  S_Kunde.Lieferlagerort as "S_Kunde.Lieferlagerort",
  S_Kunde.Kunde_seit as "S_Kunde.Kunde_seit",
  S_Kunde.lieferantennummer as "S_Kunde.lieferantennummer",
  S_Kunde.inlaendische_steuernr as "S_Kunde.inlaendische_steuernr",
  S_Kunde.waehrung as "S_Kunde.waehrung",
  S_UStID.UStID as "S_UStID.UStID",
  S_Kunde.rechnungsintervall as "S_Kunde.rechnungsintervall",
  S_Kunde.rechnungskennzeichen as "S_Kunde.rechnungskennzeichen",
  S_Kunde.rechnung_an as "S_Kunde.rechnung_an",
  S_Kunde.konzern as "S_Kunde.konzern",
  S_Konzern.Bezeichnung as "S_Konzern.Bezeichnung",
  S_Kunde.verband as "S_Kunde.verband",
  S_Verband.Bezeichnung as "S_Verband.Bezeichnung",
  S_Verband.Mahnempfaenger as "S_Verband.Mahnempfaenger",
  S_Verband.Zahlungsregulierung as "S_Verband.Zahlungsregulierung",
  S_Kunde.MembershipNoAssociation as "S_Kunde.MembershipNoAssociation",
  S_Kunde.mahnempfaenger_verband as "S_Kunde.mahnempfaenger_verband",
  S_Kunde.zinsrechnung as "S_Kunde.zinsrechnung",
  S_Kunde.stgr_mit_st as "S_Kunde.stgr_mit_st",
  S_Kunde.stgr_ohne_st as "S_Kunde.stgr_ohne_st",
  S_Kunde.stgreu_mit_st as "S_Kunde.stgreu_mit_st",
  S_Kunde.stgreu_ohne_st as "S_Kunde.stgreu_ohne_st",
  S_Kunde.stgraus_mit_st as "S_Kunde.stgraus_mit_st",
  S_Kunde.stgraus_ohne_st as "S_Kunde.stgraus_ohne_st",
  S_Kunde.zahlungsart as "S_Kunde.zahlungsart",
  S_Kunde.RemittanceAdvice as "S_Kunde.RemittanceAdvice",
  S_Kunde.zahlungsziel as "S_Kunde.zahlungsziel",
  S_Kunde.kreditlimit as "S_Kunde.kreditlimit",
  S_Kunde.kreditlimit_ueberwachen as "S_Kunde.kreditlimit_ueberwachen",
  S_Kunde.mahnverfahren as "S_Kunde.mahnverfahren",
  F_KundeVerzug.verzug as "F_KundeVerzug.verzug",
  F_KundeVerzug.gueltig_ab as "F_KundeVerzug.gueltig_ab",
  F_KundeVerzug.manuell as "F_KundeVerzug.manuell",
  S_Kunde.versandart as "S_Kunde.versandart",
  S_Kunde.lieferbedingung as "S_Kunde.lieferbedingung",
  S_Kunde.lieferrestrikt as "S_Kunde.lieferrestrikt",
  SBM_ExpCreditInsAssigns.ExpCreditInsNo as "SBM_ExpCreditInsAssigns.ExpCreditInsNo",
  SBM_ExpCreditInsAssigns.ExpCreditInsRiskNo as "SBM_ExpCreditInsAssigns.ExpCreditInsRiskNo",
  SBM_ExpCreditInsAssigns.ExpCreditInsCreditLimit as "SBM_ExpCreditInsAssigns.ExpCreditInsCreditLimit",
  SBM_ExpCreditInsAssigns.ExpCreditInsType as "SBM_ExpCreditInsAssigns.ExpCreditInsType",
  SBM_ExpCreditInsAssigns.ExpCreditInsLastInfo as "SBM_ExpCreditInsAssigns.ExpCreditInsLastInfo",
  SBM_ExpCreditInsAssigns.ValidFrom as "SBM_ExpCreditInsAssigns.ValidFrom",
  SBM_ExpCreditInsAssigns.ValidTo as "SBM_ExpCreditInsAssigns.ValidTo",
  S_Kunde.preisgruppe as "S_Kunde.preisgruppe",
  S_Kunde.rabattgruppe as "S_Kunde.rabattgruppe",
  S_Kunde.rabattart as "S_Kunde.rabattart",
  S_Kunde.fracht_skontofaehig as "S_Kunde.fracht_skontofaehig",
  S_Kunde.zuschlag_skontofaehig as "S_Kunde.zuschlag_skontofaehig",
  BBM_WflLockStatus.BBM_WflLockStatus_ID as "BBM_WflLockStatus.BBM_WflLockStatus_ID",
  S_Konto.sammelkonto as "S_Konto.sammelkonto",
  S_UStID.bestaetigt as "S_UStID.bestaetigt",
  S_BankVerb.Bankverbindung as "S_BankVerb.Bankverbindung",
  S_UStID.IsDefault as "S_UStID.IsDefault",
  SBM_DunningParameter.SBM_DunningParameter_ID as "SBM_DunningParameter.SBM_DunningParameter_ID",
  S_Kunde.I_ReportingType as "S_Kunde.I_ReportingType",
  S_Kunde.I_BalanceList as "S_Kunde.I_BalanceList",
  S_Kunde.I_TaxDelayed as "S_Kunde.I_TaxDelayed",
  S_Kunde.I_BusinessCustomer as "S_Kunde.I_BusinessCustomer",
  S_Kunde.I_NaturalPerson as "S_Kunde.I_NaturalPerson",
  S_Kunde.I_PECAccount as "S_Kunde.I_PECAccount",
  S_Kunde.I_Contract as "S_Kunde.I_Contract",
  S_Kunde.I_Carrier as "S_Kunde.I_Carrier",
  S_Kunde.I_PublicAdministrationCode as "S_Kunde.I_PublicAdministrationCode",
  S_Kunde.I_CreditLimit as "S_Kunde.I_CreditLimit",
  S_Kunde.I_RIBAGrouping as "S_Kunde.I_RIBAGrouping",
  S_Kunde.I_BlackList as "S_Kunde.I_BlackList",
  S_Kunde.F_EcoTax as "S_Kunde.F_EcoTax",
  S_Kunde.F_ActivitySector as "S_Kunde.F_ActivitySector",
  S_Kunde.F_Capital as "S_Kunde.F_Capital",
  S_Kunde.F_Siret as "S_Kunde.F_Siret",
  S_Kunde.F_TradeRegister as "S_Kunde.F_TradeRegister",
  S_Kunde.F_NoteAcceptance as "S_Kunde.F_NoteAcceptance",
  S_Kunde.F_SuggestPaym as "S_Kunde.F_SuggestPaym",
  S_Kunde.F_InvoiceSurvey as "S_Kunde.F_InvoiceSurvey",
  S_Kunde.F_FormNrDomCur as "S_Kunde.F_FormNrDomCur",
  S_Kunde.F_FormNrForCur as "S_Kunde.F_FormNrForCur",
  S_Kunde.F_NrForms as "S_Kunde.F_NrForms",
  S_Kunde.H_Kobak as "S_Kunde.H_Kobak",
  S_Kunde.CtrlGroupStateTax as "S_Kunde.CtrlGroupStateTax",
  S_Kunde.CtrlGroupStateNoTax as "S_Kunde.CtrlGroupStateNoTax",
  S_Kunde.cIN_Certificate_ImpExp as "S_Kunde.cIN_Certificate_ImpExp",
  S_Kunde.cIN_CIN as "S_Kunde.cIN_CIN",
  S_Kunde.cIN_GSTID as "S_Kunde.cIN_GSTID",
  S_Kunde.cIN_PAN as "S_Kunde.cIN_PAN",
  S_Kunde.cIN_TAN as "S_Kunde.cIN_TAN",
  S_Kunde.P_SteuerRegister as "S_Kunde.P_SteuerRegister",
  S_Kunde.P_AddPrefix4JPK as "S_Kunde.P_AddPrefix4JPK",
  S_Kunde.P_TaxTransfer2DC as "S_Kunde.P_TaxTransfer2DC",
  S_Kunde.cRU_IEC as "S_Kunde.cRU_IEC",
  S_Kunde.cRU_Rclassifyer as "S_Kunde.cRU_Rclassifyer",
  S_Kunde.cRU_DocIdentPers as "S_Kunde.cRU_DocIdentPers",
  S_Kunde.cRU_ForeignTaxID as "S_Kunde.cRU_ForeignTaxID",
  S_Kunde.cRU_PrimStRegNr as "S_Kunde.cRU_PrimStRegNr",
  S_Kunde.cRU_PrimStRegDa as "S_Kunde.cRU_PrimStRegDa",
  S_Kunde.cRU_EntCertRegNo as "S_Kunde.cRU_EntCertRegNo",
  S_Kunde.cRU_EntCerRegDate as "S_Kunde.cRU_EntCerRegDate",
  S_kunde.uCA_Betriebskalender as "S_kunde.uCA_Betriebskalender",
  S_kunde.uCW_RestrictionListing as "S_kunde.uCW_RestrictionListing",
  S_Kunde.uCW_MinDaysToExp as "S_Kunde.uCW_MinDaysToExp",
  S_Kunde.uCW_DirectPrintInvoice as "S_Kunde.uCW_DirectPrintInvoice",
  S_Kunde.uCW_VerpVorschrift as "S_Kunde.uCW_VerpVorschrift",
  S_kunde.uCW_Betriebskalender as "S_kunde.uCW_Betriebskalender",
  S_Kunde.uCI_Sammellieferschein as "S_Kunde.uCI_Sammellieferschein",
  S_Kunde.OaPText as "S_Kunde.OaPText"
FROM Customers
LEFT JOIN S_Adresse ON S_Kunde.AdressNr = S_Adresse.AdressNr
LEFT JOIN S_UStID ON S_Kunde.UStID_Nr = S_UStID.UStID_Nr
LEFT JOIN S_Konzern ON S_Kunde.konzern = S_Konzern.Konzern
LEFT JOIN S_Verband ON S_Kunde.verband = S_Verband.Verband
LEFT JOIN F_KundeVerzug ON S_Kunde.Kunde = F_KundeVerzug.Kunde
LEFT JOIN SBM_ExpCreditInsAssigns ON S_Kunde.Kunde = SBM_ExpCreditInsAssigns.Kunde
LEFT JOIN S_Konto ON S_Kunde.Konto = S_Konto.Konto
LEFT JOIN S_Bank ON S_Kunde.Bank = S_Bank.Bank